@@ -8,13 +8,28 @@ Math::Groups - Find automorphisms of groups and isomorphisms between groups.
   use Data::Dump qw(dump);
   use Math::Cartesian::Product;
 
+  # Print a cyclic group of order 4
+
+  print dump(Group{($_[0]*$_[1]) % 5} 1..4)."\n";
+
+  #   elements => {
+  #                 1 => { 1 => 1, 2 => 2, 3 => 3, 4 => 4 },
+  #                 2 => { 1 => 2, 2 => 4, 3 => 1, 4 => 3 },
+  #                 3 => { 1 => 3, 2 => 1, 3 => 4, 4 => 2 },
+  #                 4 => { 1 => 4, 2 => 3, 3 => 2, 4 => 1 },
+  #               },
+  #   identity => 1,
+  #   inverses => { 1 => 1, 2 => 3, 3 => 2, 4 => 4 },
+  #   orders   => { 1 => 0, 2 => 4, 3 => 4, 4 => 2 },
+
+
   # Find the automorphisms of the cyclic group of order 4
 
   autoMorphisms {print dump({@_})."\n"}
     Group{($_[0]+$_[1]) % 4} 0..3;
 
-  # { 1 => 1, 2 => 2, 3 => 3 }
-  # { 1 => 3, 2 => 2, 3 => 1 }
+  #   { 1 => 1, 2 => 2, 3 => 3 }
+  #   { 1 => 3, 2 => 2, 3 => 1 }
 
   # Find the automorphisms of dihedral group of order 4
 
@@ -30,12 +45,12 @@ Math::Groups - Find automorphisms of groups and isomorphisms between groups.
 	    $cornerNumbers->{$a*$c}{$b*$d}
      } 0..$#$corners;
 
-  # { 1 => 1, 2 => 2, 3 => 3 }
-  # { 1 => 1, 2 => 3, 3 => 2 }
-  # { 1 => 2, 2 => 1, 3 => 3 }
-  # { 1 => 3, 2 => 1, 3 => 2 }
-  # { 1 => 2, 2 => 3, 3 => 1 }
-  # { 1 => 3, 2 => 2, 3 => 1 }
+  #   { 1 => 1, 2 => 2, 3 => 3 }
+  #   { 1 => 1, 2 => 3, 3 => 2 }
+  #   { 1 => 2, 2 => 1, 3 => 3 }
+  #   { 1 => 3, 2 => 1, 3 => 2 }
+  #   { 1 => 2, 2 => 3, 3 => 1 }
+  #   { 1 => 3, 2 => 2, 3 => 1 }
 =cut
 
 package Math::Groups;
@@ -283,9 +298,7 @@ use vars qw(@ISA @EXPORT $VERSION);
 @ISA     = qw(Exporter);
 @EXPORT  = qw(Group autoMorphisms isoMorphisms);
 
-our $VERSION = '1.001'; # Saturday 22 Aug 2015
-
-
+our $VERSION = '1.002'; # Sunday 23 Aug 2015
 
 =head1 Description
 
